Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type RandomTopic ¶
RandomTopic is the structure for the RandomTopic.
type RenderData ¶
type RenderData struct {
NewsAnchor string
Headline string
Content template.HTML
FollowUpLink template.HTML
HeadlineLinks []string
RandomTopics []RandomTopic
Year string
CurrentYear string
MetaData MetaData
LanguageCode string
}
RenderData is the structure for the RenderData.
type Renderer ¶
type Renderer struct {
// contains filtered or unexported fields
}
Renderer is the structure for the Renderer.
func NewRenderer ¶
func (*Renderer) RenderInRandomTemplate ¶
RenderInRandomTemplate renders the given text in a random template using go templates.
func (*Renderer) SetTemplates ¶ added in v0.3.2
SetTemplates sets the templates, at the moment only used for testing.
Click to show internal directories.
Click to hide internal directories.